# studio8.r sample code

# The %in% operator
# sample with prescribed probabilities
# qbinom and off by 1 errors

#-----------------------------------
# qbinom and off by 1 errors

# k = qbinom(alpha, n, theta) gives the smallest value of k so that P(x <= k) >= alpha

#For example
n = 12
theta = 0.5
alpha = 0.05
k = qbinom(alpha, n, theta)  # k = 3
p = pbinom(k, n, theta) # p = 0.073 > 0.05
cat("k =", k, "p =", p, '\n')
# So if we want a left-sided rejection region for binom(12,0.5) with significance 0.05 we need
criticalPoint = qbinom(alpha, n, theta) - 1
rejectionRegion = 0:criticalPoint
print(criticalPoint) # 2
print(rejectionRegion) # 0,1,2
# Check
checkProb = sum(dbinom(rejectionRegion, n, theta))
print(checkProb) # 0.01928711

# Likewise for a right-sided rejection region
# **** Note the 1-alpha
criticalPoint = qbinom(1-alpha, n, theta) + 1
rejectionRegion = criticalPoint:n
print(criticalPoint) # 10
print(rejectionRegion) # 10,11,12
checkProb = sum(dbinom(rejectionRegion, n, theta))
print(checkProb) # 0.01928711

#-----------------------------
# rbinom: simulating random binomial values
# Toss a coin with 0.7 probability 10 times. Report the number of heads.
x = rbinom(1, 10, 0.7)
cat("Number of heads =", x, '\n')

# You can simulate the 10 toss experiment many times, say 16.
x = rbinom(16, 10, 0.7)
print(x)

#-----------------------------
# The %in% operator tells you if a value is in a list
rejectionRegion = c(0,1,2,14,15,16)
x = 5
reject = x %in% rejectionRegion
cat("x = ", x, ": Reject =", reject, '\n')

x = 16
reject = x %in% rejectionRegion
cat("x = ", x, ": Reject =", reject, '\n')

# You can even use it for checking if lists are in lists
x = c(1,3,5,7,9)
y = 4:8
z = x %in% y
print(z)

#----------------------------
# Sampling with prescribed probabilities
prescribedProb = c(.1,.2,.3)
range = c(2,6,10)
# Choose 1 sample from the range with the prescribed probabilities
x = sample(range, 1, prob=prescribedProb)
print(x)
x = sample(range, 1, prob=prescribedProb)
print(x)
x = sample(range, 1, prob=prescribedProb)
print(x)

# You can also choose many samples at once
x = sample(range, 8, prob=prescribedProb, replace=TRUE)
print(x)

# NOTICE THAT THE PRESCRIBED PROBABILITIES NEED NOT SUM TO 1!
# R renormalizes them to sum to 1. Here is a frequency test:

x = sample(range, 10000, prob=prescribedProb, replace=TRUE)
cat("frequency of 2 is ",sum(x==2)/10000,'\n')
cat("frequency of 6 is ",sum(x==6)/10000,'\n')
cat("frequency of 10 is ",sum(x==10)/10000,'\n')

# the prescribed probabilities have been divided by (.1 + .2 + .3)
# to become (1/6,1/3,1/2). We could even write

y = sample(range, 10000, prob=c(1,2,3), replace=TRUE)
cat("frequency of 2 is ",sum(x==2)/10000,'\n')
cat("frequency of 6 is ",sum(x==6)/10000,'\n')
cat("frequency of 10 is ",sum(x==10)/10000,'\n')